package core.thrift;

import org.apache.commons.pool2.BasePooledObjectFactory;
import org.apache.commons.pool2.PooledObject;
import org.apache.commons.pool2.impl.DefaultPooledObject;
import org.apache.thrift.transport.TTransport;

import java.net.Socket;

public abstract class TTransportPool<T extends TTransport, C> extends BasePooledObjectFactory<T> {

    protected SocketConfig config;

    public TTransportPool(SocketConfig config) {
        this.config = config;
    }

    @Override
    public PooledObject<T> wrap(T transport) {
        return new DefaultPooledObject<>(transport);
    }

    /**
     * 验证对象
     */
    @Override
    public boolean validateObject(PooledObject<T> p) {
        Socket socket = socket(p.getObject());
        boolean closed = socket.isClosed();
        boolean connected = socket.isConnected();
        boolean outputShutdown = socket.isOutputShutdown();
        boolean inputShutdown = socket.isInputShutdown();

        boolean urgentFlag = false;
        try {
            socket.sendUrgentData(0xFF);
            urgentFlag = true;
        } catch (Exception e) {

        }

        return urgentFlag && connected && !closed && !inputShutdown && !outputShutdown;
    }

    /**
     * 获取socket
     */
    public abstract Socket socket(T o);


    /**
     * 销毁对象
     */
    @Override
    public void destroyObject(PooledObject<T> p) {
        p.getObject().close();
    }
}






